@@ -1,7 +1,5 @@
 """Sample API Client."""
-from cgitb import enable
 import logging
-from sqlite3 import enable_shared_cache
 from typing import Optional, Dict, Any, List
 import aiohttp
 from datetime import datetime, timedelta
